@@ -923,7 +923,6 @@ return [
     'Auto' => 'Auto',
     'Related' => 'Relacionat',
     'Attachment' => 'Adjunt',
-    'Title not found' => 'Títol no trobat',
     'Web Link' => 'Enllaç web',
     'External links' => 'Enllaços externs',
     'Add external link' => 'Afegeix un enllaç extern',
@@ -1468,6 +1467,6 @@ return [
     'Add attachments' => 'Afegir adjunts',
     'Task #%d "%s" is overdue' => 'Tasca #%d "%s" ha caducat',
     'Enable notifications by default for all new users' => 'Habilitar notificacions per defecte per a tots els nous usuaris',
-    // 'Assign the task to its creator for specific columns if no assignee is set manually' => '',
-    // 'Assign a task to the logged user on column change to specified column if no user is assigned' => '',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Assigna la tasca al seu creador per a columnes específiques si no s\'ha definit cap responsable manualment',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Assigna una tasca a l\'usuari connectat en canviar de columna a la columna especificada si no hi ha cap usuari assignat',
 ];
