@@ -923,7 +923,6 @@ return [
     'Auto' => 'Auto',
     'Related' => 'Relacionado',
     'Attachment' => 'Archivo adjunto',
-    'Title not found' => 'Título no encontrado',
     'Web Link' => 'Enlace web',
     'External links' => 'Enlaces externos',
     'Add external link' => 'Añadir enlace externo',
@@ -1468,4 +1467,6 @@ return [
     'Add attachments' => 'Agregar archivos adjuntos',
     'Task #%d "%s" is overdue' => 'La tarea #%d "%s" está vencida',
     'Enable notifications by default for all new users' => 'Habilitar notificaciones por defecto para todos los nuevos usuarios',
+    'Assign the task to its creator for specific columns if no assignee is set manually' => 'Asignar la tarea a su creador para columnas específicas si no se ha establecido un responsable manualmente',
+    'Assign a task to the logged user on column change to specified column if no user is assigned' => 'Asignar una tarea al usuario conectado al cambiar de columna a la columna especificada si no hay ningún usuario asignado',
 ];
